<form name="form" class="list">
  <label class="item item-input">
    <input name="name" ng-model="data.name" placeholder="{{'Name' | translate}}" type="text">
  </label>
  <label class="item item-input">
    <input name="url" ng-model="data.url" placeholder="http://example.com/stream.mp3" type="text">
  </label>
</form>
